@@ -6,7 +6,40 @@ from django.conf import settings
 from django.forms.util import flatatt
 from django.utils.encoding import force_unicode
 from django.utils.safestring import mark_safe
+from django.utils.encoding import force_text
+from django.utils.html import format_html
+from itertools import chain
 
+class CountrySelect(forms.Select):
+    allow_multiple_selected = False
+    
+    def render(self, name, value, attrs=None, choices=()):
+        print "\n\nRENDERRRR"
+        if value is None: value = ''
+        final_attrs = self.build_attrs(attrs, name=name)
+        output = [format_html('<select{0}>', flatatt(final_attrs))]
+        options = self.render_options(choices, [value])
+        if options:
+            output.append(options)
+        output.append('</select>')
+        return mark_safe('\n'.join(output))
+
+    def render_options(self, choices, selected_choices):
+        
+        # Normalize to strings.
+        selected_choices = set(force_text(v) for v in selected_choices)
+        output = []
+        
+        for option_value, option_label in chain(self.choices, choices):
+            if isinstance(option_label, (list, tuple)):
+                output.append(format_html('<optgroup label="{0}" class="{1}">', force_text(option_value),force_text(option_value.replace(" ","-").lower())))
+                for option in option_label:
+                    output.append(self.render_option(selected_choices, *option))
+                output.append('</optgroup>')
+            else:
+                output.append(self.render_option(selected_choices, option_value, option_label))
+        return '\n'.join(output)
+    
 class NullCheckboxWidget(forms.CheckboxInput):
     
     def render(self, name, value, attrs=None):
